Na tej stronie opisano, jak wykonywać zadania związane z kluczami szyfrowania zarządzanymi przez klienta (CMEK) w Cloud Firestore. Więcej ogólnych informacji o kluczach CMEK, w tym o tym, kiedy i dlaczego warto je włączyć, znajdziesz w dokumentacji Cloud KMS.
Przygotowanie kluczy CMEK
Zanim utworzysz bazę danych Cloud Firestore chronioną kluczami CMEK, musisz wykonać te czynności:
- Poproś o dostęp do funkcji klucza CMEK Cloud Firestore.
- Utwórz (lub pobierz) agenta usługi Cloud Firestore.
- Utwórz klucz CMEK.
- Skonfiguruj ustawienia uprawnień dla tego klucza.
Wykonaj te czynności w przypadku każdego projektu, który będzie zawierać bazy danych Cloud Firestore chronione kluczami CMEK. Jeśli później utworzysz nowy klucz CMEK, musisz skonfigurować dla niego ustawienia uprawnień.
Poproś o dostęp
Zanim utworzysz agenta usługi Cloud Firestore, poproś o dostęp do funkcji CMEK, wypełniając ten formularz.
Tworzenie agenta usługi Cloud Firestore
Zanim utworzysz klucz CMEK, musisz mieć agenta usługi Cloud Firestore, który jest typem zarządzanego przez Google konta usługi używanego przez Cloud Firestore do uzyskiwania dostępu do klucza.
Uruchom polecenie services identity create, aby utworzyć agenta usługi, którego Cloud Firestore używa do uzyskiwania dostępu do klucza CMEK w Twoim imieniu. To polecenie tworzy konto usługi, jeśli jeszcze nie istnieje, a następnie je wyświetla.
gcloud beta services identity create \
--service=firestore.googleapis.com \
--project FIRESTORE_PROJECT
Zastąp FIRESTORE_PROJECT projektem, którego chcesz używać w bazach danych Cloud Firestore.
Polecenie wyświetla identyfikator agenta usługi, który jest sformatowany jak adres e-mail. Zapisz ciąg znaków adresu e-mail, ponieważ będzie Ci potrzebny w jednym z kolejnych kroków.
Service identity created: service-xxx@gcp-sa-firestore.iam.gserviceaccount.com
Utwórz klucz
Możesz użyć klucza utworzonego bezpośrednio w Cloud KMS lub klucza zarządzanego zewnętrznie, który udostępniasz za pomocą Cloud External Key Manager.
Lokalizacja klucza Cloud KMS musi być taka sama jak lokalizacja bazy danych Cloud Firestore, z którą będzie on używany.
W przypadku regionalnych lokalizacji baz danych używaj tej samej nazwy lokalizacji dla pęku kluczy, klucza i bazy danych, ponieważ nazwy lokalizacji są mapowane w relacji jeden do jednego.
Jeśli na przykład chcesz utworzyć bazę danych chronioną kluczem CMEK w regionie
us-west1, utwórz pęk kluczy i klucz w regionieus-west1.W przypadku lokalizacji baz danych obejmujących wiele regionów użyj nazwy lokalizacji KMS obejmującej wiele regionów:
- Użyj lokalizacji Cloud KMS w wielu regionach
usdla lokalizacji Cloud Firestorenam5w wielu regionach. - Użyj lokalizacji Cloud KMS w wielu regionach
europedla lokalizacji Cloud Firestoreeur3w wielu regionach.
- Użyj lokalizacji Cloud KMS w wielu regionach
W projekcie Google Cloud, w którym chcesz zarządzać kluczami, wykonaj te czynności:
Utwórz pęk kluczy i klucz, korzystając z jednej z tych opcji:
- Utwórz pęk kluczy i klucz bezpośrednio w Cloud KMS.
- używać klucza zarządzanego zewnętrznie, Utwórz klucz zewnętrzny, a następnie utwórz klucz Cloud EKM, aby udostępnić go w Cloud KMS.
Konfigurowanie ustawień uprawnień dla klucza
Konsola
Aby przypisać rolę Cloud KMS do agenta usługi, wykonaj te czynności. Jeśli chcesz uzyskać mniejszą szczegółowość, możesz też przyznać uprawnienia na poziomie klucza lub pęku kluczy.
W konsoli Google Cloud otwórz stronę Uprawnienia.
Kliknij Dodaj.
Wpisz identyfikator agenta usługi Cloud Firestore w formacie adresu e-mail.
Wybierz rolę Szyfrujący i odszyfrowujący klucze CryptoKey Cloud KMS.
Kliknij Zapisz.
gcloud
Przypisz rolę cloudkms.cryptoKeyEncrypterDecrypter do agenta usługi:
gcloud kms keys add-iam-policy-binding KMS_KEY \
--keyring KMS_KEYRING\
--location KMS_LOCATION \
--member serviceAccount:SERVICE_AGENT_EMAIL \
--role roles/cloudkms.cryptoKeyEncrypterDecrypter \
--project KMS_PROJECT
Zastąp następujące elementy:
KMS_KEYnazwą przypisaną do klucza,KMS_KEYRINGpękiem kluczy KMS zawierającym klucz,KMS_LOCATIONregionem zawierającym pęk kluczy,SERVICE_AGENT_EMAILidentyfikatorem w formacie adresu e-mail agenta usługi, któremu przyznajesz dostęp;KMS_PROJECTz projektem zawierającym klucz,
Terminal powinien wyświetlić odpowiedź podobną do tej:
Updated IAM policy for key KMS_KEY.
bindings:
- members:
- serviceAccount:
service-{project-number}@gcp-sa-firestore.iam.gserviceaccount.com
role: roles/cloudkms.cryptoKeyEncrypterDecrypter
Tworzenie bazy danych obsługującej klucze CMEK
Po utworzeniu i skonfigurowaniu kluczy CMEK możesz utworzyć bazę danych chronioną kluczem CMEK. Istniejących baz danych Cloud Firestore, które są chronione przez domyślne szyfrowanie Google, nie można przekonwertować na korzystanie z kluczy CMEK.
Typ szyfrowania i klucz możesz wybrać tylko podczas tworzenia bazy danych z obsługą kluczy CMEK.
Konsola
W konsoli Google Cloud otwórz stronę Bazy danych.
Kliknij Utwórz bazę danych.
Wybierz tryb bazy danych. Kliknij Dalej.
Na stronie Skonfiguruj bazę danych wpisz identyfikator bazy danych.
Wybierz lokalizację.
Kliknij Pokaż opcje szyfrowania, a następnie wybierz Klucz Cloud KMS.
Wybierz lub wpisz nazwę zasobu klucza CMEK, którego chcesz używać w bazie danych.
Lista kluczy jest ograniczona do bieżącego projektu Google Cloud i wybranej lokalizacji bazy danych. Aby użyć klucza z innego projektu Google Cloud, kliknij Przełącz projekt lub Wpisz klucz ręcznie.
Jeśli pojawi się prośba o przyznanie uprawnień do klucza kontu usługi Cloud Firestore, kliknij Przyznaj. Aby utworzyć bazę danych CMEK, Twoje konto usługi Cloud Firestore musi mieć przypisaną rolę
cloudkms.cryptoKeyEncrypterDecrypter.Wybierz reguły zabezpieczeń dla klientów mobilnych i internetowych.
Kliknij Utwórz bazę danych.
Po utworzeniu bazy danych możesz sprawdzić, czy obsługuje ona klucze CMEK, wyświetlając Szczegóły bazy danych:
- Jeśli baza danych jest chroniona przez CMEK, pole Typ szyfrowania ma wartość Zarządzane przez klienta, a w polu Klucz szyfrowania jest podany odpowiedni klucz Cloud KMS i wersja klucza używana do ochrony tej bazy danych.
- Jeśli baza danych nie jest chroniona przez CMEK, w polu Typ szyfrowania wyświetla się Zarządzane przez Google.
gcloud
Zanim utworzysz bazę danych obsługującą klucze CMEK za pomocą Google Cloud CLI, zainstaluj najnowszą wersję i autoryzuj gcloud CLI. Więcej informacji znajdziesz w artykule na temat instalowania gcloud CLI.
gcloud firestore databases create --location=FIRESTORE_DATABASE_LOCATION \
--database=DATABASE_ID \
--kms-key-name=KMS_KEY_NAME \
--project=FIRESTORE_PROJECT
Zastąp następujące elementy:
FIRESTORE_DATABASE_LOCATION, podając lokalizację bazy danych Cloud Firestore.DATABASE_IDidentyfikatorem bazy danych,KMS_KEY_NAMEnazwą przypisaną do klucza. Użyj pełnej nazwy zasobu klucza w tym formacie:projects/KMS_PROJECT/locations/KMS_LOCATION/keyRings/KMS_KEYRING_ID/cryptoKeys/KMS_KEY_IDFIRESTORE_PROJECTz projektem, który ma być używany w bazie danych Cloud Firestore
Interfejs API typu REST
Żądanie HTTP:
POST https://firestore.googleapis.com/v1/projects/{FIRESTORE_PROJECT}/databases
W treści żądania skonfiguruj klucz CMEK w polu cmek_config.kms_key_name.
Ustaw pełny identyfikator zasobu klucza Cloud KMS. Dozwolony jest tylko klucz w tej samej lokalizacji co ta baza danych.
Ta wartość powinna być identyfikatorem zasobu klucza Cloud KMS w formacie projects/{KMS_PROJECT}/locations/{KMS_LOCATION}/keyRings/{KMS_KEYRING_ID}/cryptoKeys/{KMS_KEY_ID}
Więcej informacji o innych polach znajdziesz na stronie database create.
Przykładowe żądanie:
curl -X POST 'https://firestore.googleapis.com/v1/projects/FIRESTORE_PROJECT/databases?databaseId={DATABASE_ID}' \
-H "Authorization: Bearer $(gcloud auth print-access-token)" \
-H "Content-type: application/json" \
-d '{
"type":"FIRESTORE_NATIVE",
"locationId":"{FIRESTORE_DATABASE_LOCATION}",
"cmekConfig": {
"kmsKeyName":"projects/KMS_PROJECT/locations/KMS_LOCATION/keyRings/KMS_KEYRING_ID/cryptoKeys/KMS_KEY_ID"
}
}'
wiersz poleceń Firebase
Aby utworzyć bazę danych z włączonym kluczem CMEK, użyj pola Nazwa klucza KMS. Jeśli nie określisz parametru --kms-key-name, Cloud Firestore domyślnie utworzy bazę danych bez kluczy CMEK.
firebase firestore:databases:create DATABASE_ID
--location LOCATION
--kms-key-name projects/KMS_PROJECT/locations/KMS_LOCATION/keyRings/KMS_KEYRING_ID/cryptoKeys/KMS_KEY_ID
--project FIRESTORE_PROJECT
Zastąp następujące elementy:
DATABASE_IDidentyfikatorem bazy danych,LOCATIONz lokalizacją bazy danych,KMS_PROJECTz projektem, który zawiera klucz CMEK;KMS_LOCATIONlokalizacją zawierającą klucz CMEK i pęk kluczy,KMS_KEYRING_IDidentyfikatorem pęku kluczy CMEK,FIRESTORE_PROJECTz projektem, który ma być używany w bazie danych Cloud Firestore
Potwierdź, że baza danych Cloud Firestore jest chroniona za pomocą interfejsu wiersza poleceń Firebase:
firebase firestore:databases:get DATABASE_ID --project FIRESTORE_PROJECT
W odpowiedzi pojawią się te informacje o kluczu CMEK:
- Pole Nazwa klucza KMS zawiera pełną nazwę zasobu klucza, który jest używany do szyfrowania bazy danych CMEK Cloud Firestore.
- Pole Aktywne wersje kluczy zawiera listę wszystkich wersji kluczy używanych obecnie przez tę bazę danych CMEK. Podczas rotacji kluczy możesz mieć wiele aktywnych wersji kluczy.
Terraform
Aby utworzyć bazę danych z obsługą kluczy CMEK, użyj zasobu google_firestore_database. Więcej informacji i przykładów znajdziesz w artykule google_firestore_database.
resource "google_firestore_database" "database" {
project = "FIRESTORE_PROJECT"
name = "DATABASE_ID"
location_id = "FIRESTORE_DATABASE_LOCATION"
type = "DATABASE_TYPE"
cmek_config {
kms_key_name = "KMS_KEY_NAME"
}
}
Zastąp następujące elementy:
FIRESTORE_PROJECTz projektem, który ma być używany w bazie danych Cloud FirestoreDATABASE_IDidentyfikatorem bazy danych,FIRESTORE_DATABASE_LOCATION, podając lokalizację bazy danych Cloud Firestore.DATABASE_TYPEzFIRESTORE_NATIVEw przypadku trybu natywnego lubDATASTORE_MODEw przypadku trybu Datastore.KMS_KEY_NAMEnazwą przypisaną do klucza. Użyj pełnej nazwy zasobu klucza w formacie:projects/KMS_PROJECT/locations/KMS_LOCATION/keyRings/KMS_KEYRING_ID/cryptoKeys/KMS_KEY_ID
Uzyskiwanie dostępu do bazy danych chronionej kluczem CMEK
Wszystkie operacje odczytu, zapisu i zapytania wysyłane do bazy danych chronionej kluczem CMEK powinny działać tak samo jak w przypadku bazy danych zaszyfrowanej domyślnie przez Google. Na przykład nie musisz podawać klucza w każdym żądaniu.
Przywracanie bazy danych chronionej kluczem CMEK
Zanim przywrócisz bazę danych chronioną kluczem CMEK z kopii zapasowej:
- Zdecyduj, czy chcesz przywrócić bazę danych z szyfrowaniem CMEK, domyślnym szyfrowaniem Google (bez CMEK) czy z tym samym szyfrowaniem co kopia zapasowa.
Przygotuj klucz (wersję podstawową) i wersję klucza, która została użyta do zaszyfrowania kopii zapasowej. Włącz klucz i wersję klucza.
gcloud
Przywracanie bazy danych chronionej kluczem CMEK do szyfrowania CMEK
Aby przywrócić szyfrowanie CMEK, uruchom polecenie gcloud firestore databases restore z opcjonalnymi flagami encryption-type i kms-key-name, aby skonfigurować typ szyfrowania przywróconej bazy danych. Jeśli nie określisz typu szyfrowania, przywrócona baza danych będzie używać tej samej konfiguracji szyfrowania co kopia zapasowa.
gcloud firestore databases restore
--encryption-type=customer-managed-encryption
--kms-key-name=KMS_KEY_NAME
Zastąp KMS_KEY_NAME nazwą przypisaną do klucza. Użyj pełnej nazwy zasobu klucza w tym formacie:
projects/KMS_PROJECT/locations/KMS_LOCATION/keyRings/KMS_KEYRING_ID/cryptoKeys/KMS_KEY_ID
Przywracanie domyślnego szyfrowania bazy danych chronionej kluczem CMEK
Aby przywrócić domyślne szyfrowanie Google (inne niż CMEK), ustaw flagę encryption-type w ten sposób:
gcloud firestore databases restore
--encryption-type=google-default-encryption
Przywracanie bazy danych chronionej kluczem CMEK do tego samego typu szyfrowania co kopia zapasowa
Aby przywrócić ten sam typ szyfrowania co w kopii zapasowej, ustaw flagę encryption-type w ten sposób:
gcloud firestore databases restore --encryption-type=use-source-encryption
wiersz poleceń Firebase
Przywracanie bazy danych chronionej kluczem CMEK do szyfrowania CMEK
Aby przywrócić szyfrowanie CMEK, użyj opcjonalnych flag encryption-type i kms-key-name.
Jeśli nie określisz typu szyfrowania, przywrócona baza danych będzie używać tej samej konfiguracji szyfrowania co kopia zapasowa.
firebase firestore:databases:restore \
--database DATABASE_ID \
--backup 'projects/FIRESTORE_PROJECT/locations/FIRESTORE_LOCATION/backups/BACKUP_ID' \
--encryption-type CUSTOMER_MANAGED_ENCRYPTION \
--kms-key-name projects/KMS_PROJECT/locations/KMS_LOCATION/keyRings/KMS_KEYRING_ID/cryptoKeys/KMS_KEY_ID \
--project FIRESTORE_PROJECT
Zastąp następujące elementy:
DATABASE_IDidentyfikatorem bazy danych,FIRESTORE_PROJECTz projektem, który ma być używany w bazie danych Cloud FirestoreFIRESTORE_LOCATION, podając lokalizację bazy danych Cloud Firestore.BACKUP_IDidentyfikatorem kopii zapasowej.KMS_PROJECTz projektem, który zawiera klucz CMEK;KMS_LOCATIONlokalizacją zawierającą klucz CMEK i pęk kluczy,KMS_KEYRING_IDidentyfikatorem pęku kluczy CMEK,
Sprawdź, czy przywrócona baza danych Cloud Firestore jest zaszyfrowana kluczami CMEK:
firebase firestore:databases:get DATABASE_ID --project FIRESTORE_PROJECT
Przywracanie domyślnego szyfrowania bazy danych chronionej kluczem CMEK
Aby przywrócić domyślne szyfrowanie Google (inne niż CMEK), ustaw flagę encryption-type w ten sposób:
firebase firestore:databases:restore \
--database DATABASE_ID \
--backup 'projects/FIRESTORE_PROJECT/locations/FIRESTORE_LOCATION/backups/BACKUP_ID' \
--encryption-type GOOGLE_DEFAULT_ENCRYPTION \
--project FIRESTORE_PROJECT
Zastąp następujące elementy:
DATABASE_IDidentyfikatorem bazy danych,FIRESTORE_PROJECTz projektem, który ma być używany w bazie danych Cloud FirestoreFIRESTORE_LOCATION, podając lokalizację bazy danych Cloud Firestore.BACKUP_IDidentyfikatorem kopii zapasowej.
Przywracanie bazy danych chronionej kluczem CMEK do tego samego typu szyfrowania co kopia zapasowa
Aby przywrócić ten sam typ szyfrowania co w kopii zapasowej, ustaw flagę encryption-type w ten sposób:
firebase firestore:databases:restore \
--database DATABASE_IDD \
--backup 'projects/FIRESTORE_PROJECT/locations/FIRESTORE_LOCATION/backups/BACKUP_ID' \
--encryption-type USE_SOURCE_ENCRYPTION
Zastąp następujące elementy:
DATABASE_IDidentyfikatorem bazy danych,FIRESTORE_PROJECTz projektem, który ma być używany w bazie danych Cloud FirestoreFIRESTORE_LOCATION, podając lokalizację bazy danych Cloud Firestore.BACKUP_IDidentyfikatorem kopii zapasowej.
Klonowanie bazy danych chronionej kluczem CMEK
Zanim sklonujesz bazę danych chronioną kluczem CMEK:
- Zdecyduj, czy chcesz sklonować bazę danych do szyfrowania CMEK, do domyślnego szyfrowania Google (bez CMEK) czy do tego samego szyfrowania co źródłowa baza danych.
Przygotuj klucz (wersja podstawowa) i wersję klucza, które zostały użyte do zaszyfrowania źródłowej bazy danych. Włącz klucz i wersję klucza.
gcloud
Klonowanie bazy danych chronionej kluczem CMEK do szyfrowania CMEK
Aby sklonować do szyfrowania CMEK, uruchom polecenie gcloud firestore databases clone z opcjonalnymi flagami encryption-type i kms-key-name, aby skonfigurować typ szyfrowania sklonowanej bazy danych. Jeśli nie określisz typu szyfrowania, sklonowana baza danych będzie używać tej samej konfiguracji szyfrowania co źródłowa baza danych.
gcloud firestore databases clone \
--encryption-type=customer-managed-encryption \
--kms-key-name=KMS_KEY_NAME
Zastąp KMS_KEY_NAME nazwą przypisaną do klucza. Użyj pełnej nazwy zasobu klucza w tym formacie:
projects/KMS_PROJECT/locations/KMS_LOCATION/keyRings/KMS_KEYRING_ID/cryptoKeys/KMS_KEY_ID
Klonowanie bazy danych chronionej kluczem CMEK do domyślnego szyfrowania
Aby sklonować do domyślnego szyfrowania Google (bez CMEK), ustaw flagę encryption-type w ten sposób:
gcloud firestore databases clone \
--encryption-type=google-default-encryption
Klonowanie bazy danych chronionej kluczem CMEK do tego samego typu szyfrowania co źródłowa baza danych
Aby sklonować do tego samego typu szyfrowania co źródłowa baza danych, ustaw flagę encryption-type w następujący sposób:
gcloud firestore databases clone \
--encryption-type=use-source-encryption
Jest to też działanie domyślne, jeśli parametr --encryption-type nie jest określony.
wiersz poleceń Firebase
Klonowanie bazy danych chronionej kluczem CMEK do szyfrowania CMEK
Aby sklonować do szyfrowania CMEK, uruchom polecenie firebase firestore:databases:clone z opcjonalnymi flagami encryption-type i kms-key-name, aby skonfigurować typ szyfrowania sklonowanej bazy danych. Jeśli nie określisz typu szyfrowania, sklonowana baza danych będzie używać tej samej konfiguracji szyfrowania co źródłowa baza danych.
firebase firestore:databases:clone \
SOURCE_DATABASE \
DESTINATION_DATABASE \
--encryption-type=CUSTOMER_MANAGED_ENCRYPTION \
--kms-key-name=KMS_KEY_NAME
Zastąp KMS_KEY_NAME nazwą przypisaną do klucza. Użyj pełnej nazwy zasobu klucza w tym formacie:
projects/KMS_PROJECT/locations/KMS_LOCATION/keyRings/KMS_KEYRING_ID/cryptoKeys/KMS_KEY_ID
Klonowanie bazy danych chronionej kluczem CMEK do domyślnego szyfrowania
Aby sklonować do domyślnego szyfrowania Google (bez CMEK), ustaw flagę encryption-type w ten sposób:
firebase firestore:databases:clone \
SOURCE_DATABASE \
DESTINATION_DATABASE \
--encryption-type=GOOGLE_DEFAULT_ENCRYPTION
Klonowanie bazy danych chronionej kluczem CMEK do tego samego typu szyfrowania co źródłowa baza danych
Aby sklonować do tego samego typu szyfrowania co źródłowa baza danych, ustaw flagę encryption-type w następujący sposób:
firebase firestore:databases:clone \
SOURCE_DATABASE \
DESTINATION_DATABASE \
--encryption-type=USE_SOURCE_ENCRYPTION
Jest to też działanie domyślne, jeśli parametr --encryption-type nie jest określony.
Wyświetlanie używanego klucza
gcloud
Aby sprawdzić konfigurację klucza CMEK bazy danych, możesz użyć polecenia databases describe gcloud CLI:
gcloud firestore databases describe --database=DATABASE_ID --project=FIRESTORE_PROJECT
W odpowiedzi w polu cmekConfig powinny pojawić się informacje o kluczach CMEK podobne do tych:
cmekConfig:
activeKeyVersion:
- projects/PROJECT_ID/locations/us/keyRings/KEYRING_NAME/cryptoKeys/KEY_NAME/cryptoKeyVersions/1
kmsKeyName: projects/PROJECT_ID/locations/us/keyRings/KEYRING_NAME/cryptoKeys/KEY_NAME
locationId: nam5
name: projects/PROJECT_ID/databases/DATABASE_ID
Odpowiedź zawiera te informacje:
kmsKeyName: pełna nazwa zasobu klucza używanego do szyfrowania bazy danych chronionej przez CMEK.activeKeyVersion: lista wszystkich wersji kluczy używanych obecnie przez bazę danych chronioną kluczem CMEK. Podczas rotacji kluczy możesz mieć wiele aktywnych wersji kluczy. Podczas rotacji kluczy muszą być dostępne zarówno stara, jak i nowa wersja klucza. Nie wyłączaj starej wersji klucza, dopóki nie przestanie się ona pojawiać w poluactiveKeyVersion.
Interfejs API typu REST
Żądanie HTTP:
GET https://firestore.googleapis.com/v1/{name=projects/FIRESTORE_PROJECT/databases/DATABASE_ID}
W treści żądania skonfiguruj klucz CMEK w polu cmek_config.kms_key_name.
Ustaw pełny identyfikator zasobu klucza Cloud KMS. Dozwolony jest tylko klucz w tej samej lokalizacji co ta baza danych.
Ta wartość powinna być identyfikatorem zasobu klucza Cloud KMS w formacie projects/{KMS_PROJECT}/locations/{KMS_LOCATION}/keyRings/{KMS_KEYRING_ID}/cryptoKeys/{KMS_KEY_ID}
Więcej informacji o innych polach znajdziesz na stronie database create.
Przykładowe żądanie i odpowiedź:
curl 'https://firestore.googleapis.com/v1/projects/FIRESTORE_PROJECT/databases/{DATABASE_ID}' \
-H "Authorization: Bearer $(gcloud auth print-access-token)" \
-H "Content-type: application/json"
—----------------------------------------- Response —--------------------------------------------
{
"name": "projects/FIRESTORE_PROJECT/databases/{DATABASE_ID}",
"locationId": "{FIRESTORE_DATABASE_LOCATION}",
"type": "FIRESTORE_NATIVE",
"cmekConfig": {
"kmsKeyName": "projects/{KMS_PROJECT}/locations/{KMS_LOCATION}/keyRings/{KMS_KEYRING_ID}/cryptoKeys/{KMS_KEY_ID}",
"activeKeyVersion": [
"projects/{KMS_PROJECT}/locations/{KMS_LOCATION}/keyRings/{KMS_KEYRING_ID}/cryptoKeys/{KMS_KEY_ID}/cryptoKeyVersions/1"
]
},
……
}
Wyłączanie klucza
Aby wyłączyć klucz powiązany z bazą danych, wykonaj te czynności:
- Wyświetlanie wersji kluczy używanych w bazie danych
- Wyłącz te używane wersje klucza.
- Poczekaj, aż zmiana zostanie wprowadzona, i sprawdź, czy dane nie są już dostępne. Zmiany zwykle zaczynają obowiązywać w ciągu kilku minut, ale ich zastosowanie może potrwać do 3 godzin.
Gdy klucz używany przez bazę danych jest wyłączony, możesz otrzymać wyjątek FAILED_PRECONDITION z dodatkowymi szczegółami w komunikacie o błędzie, na przykład:
{ "error": { "code": 400, "message": "The customer-managed encryption key required by the requested resource is not accessible. Error reason: generic::permission_denied: Permission 'cloudkms.cryptoKeyVersions.useToEncrypt' denied on resource 'projects/FIRESTORE_PROJECT/locations/{KMS_LOCATION}/keyRings/{KMS_KEYRING_ID}/cryptoKeys/{KMS_KEY_ID}' (or it may not exist).", "status": "FAILED_PRECONDITION", "details": [ { "@type": "type.googleapis.com/google.rpc.DebugInfo", "detail": "The customer-managed encryption key required by the requested resource is not accessible. Error reason: generic::permission_denied: Permission 'cloudkms.cryptoKeyVersions.useToEncrypt' denied on resource 'projects/FIRESTORE_PROJECT/locations/{KMS_LOCATION}/keyRings/{KMS_KEYRING_ID}/cryptoKeys/{KMS_KEY_ID}' (or it may not exist)" } ] } }
Włączanie klucza
Aby ponownie włączyć klucz powiązany z bazą danych, wykonaj te czynności:
- Wyświetlanie wersji kluczy używanych w bazie danych
- Włącz te używane wersje klucza
- Poczekaj, aż zmiana zostanie wprowadzona, i sprawdź, czy dane nie są już dostępne. Zmiany zwykle zaczynają obowiązywać w ciągu kilku minut, ale ich zastosowanie może potrwać do 3 godzin.
Wyświetlanie logów kontrolnych klucza Cloud KMS
Zanim włączysz logi kontrolne dostępu do danych w Cloud KMS, zapoznaj się z logami kontrolnymi Cloud.
Logi kontrolne dostępu do danych Cloud KMS pokazują, kiedy Cloud Firestore lub inne usługi skonfigurowane do korzystania z klucza CMEK wykonują wywołania szyfrowania/odszyfrowywania do Cloud KMS. Cloud Firestore nie wysyła wywołania szyfrowania/odszyfrowywania przy każdym żądaniu danych, ale utrzymuje proces, który okresowo sprawdza klucz. Wyniki ankiety pojawią się w dziennikach kontrolnych.
Logi kontrolne możesz skonfigurować i korzystać z nich w konsoli Google Cloud:
Upewnij się, że w projekcie włączone jest logowanie dla interfejsu Cloud KMS API.
W konsoli Google Cloud otwórz Cloud Logging.
Ogranicz wpisy logu do klucza Cloud KMS, dodając do kreatora zapytań te wiersze:
resource.type="cloudkms_cryptokey" resource.labels.key_ring_id = KMS_KEYRING resource.labels.crypto_key_id = KMS_KEY resource.labels.location=KMS_LOCATIONZastąp następujące elementy:
KMS_KEYna nazwę klucza CMEK,KMS_KEYRINGpękiem kluczy KMS zawierającym klucz,KMS_LOCATIONz lokalizacją klucza i pęku kluczy.
Dziennik zawiera kilka wpisów logu co około 5 minut na bazę danych. Wpisy logu wyglądają podobnie do tych przykładów:
Info 2021-03-20 08:02:24.869 EDT Cloudkms.googleapis.com Decrypt projects/cloud-kms-project/locations/us-central1/keyRings/firestore-keys/cryptoKeys/my-cmek-key service-123456789123@gcp-sa-firestore.iam.gserviceaccount.com audit_log, method: "Decrypt", principal_email: "service-1234567891011@gcp-sa-firestore.iam.gserviceaccount.com" Info 2021-03-20 08:02:24.913 EDT Cloudkms.googleapis.com Encrypt projects/cloud-kms-project/locations/us-central1/keyRings/firestore-keys/cryptoKeys/my-cmek-key service-123456789123@gcp-sa-firestore.iam.gserviceaccount.com audit_log, method: "Encrypt", principal_email: "service-123456789123@gcp-sa-firestore.iam.gserviceaccount.com"
Szczegółowe informacje o interpretowaniu logów kontrolnych znajdziesz w artykule Informacje o logach kontrolnych.
Konfigurowanie zasady organizacji dotyczącej kluczy CMEK
Aby określić wymagania dotyczące zgodności szyfrowania baz danych Cloud Firestore w organizacji, użyj ograniczenia zasad organizacji dotyczącego CMEK.
Wymagaj ochrony kluczem CMEK
Skonfiguruj constraints/gcp.restrictNonCmekServices, aby wymagać kluczy CMEK do tworzenia baz danych Cloud Firestore. Ustaw ograniczenie na deny i dodaj firestore.googleapis.com do listy odrzuconych, na przykład:
gcloud resource-manager org-policies deny gcp.restrictNonCmekServices is:firestore.googleapis.com --project=FIRESTORE_PROJECT
Zastąp FIRESTORE_PROJECT projektem, który chcesz ograniczyć.
Więcej informacji o konfigurowaniu zasad organizacji znajdziesz w artykule o tworzeniu i edytowaniu zasad.
Po wejściu zasady w życie, jeśli spróbujesz utworzyć bazę danych bez kluczy CMEK w projekcie, którego dotyczy zasada, otrzymasz wyjątek FAILED_PRECONDITION i komunikat o błędzie. Wyjątek wygląda na przykład tak:
{ "error": { "code": 400, "message": "Constraint 'constraints/gcp.restrictNonCmekServices' violated for 'projects/FIRESTORE_PROJECT' attempting to perform the operation 'google.firestore.admin.v1.FirestoreAdmin.CreateDatabase' with violated value 'firestore.googleapis.com'. See https://cloud.google.com/resource-manager/docs/organization-policy/org-policy-constraints for more information.", "status": "FAILED_PRECONDITION", "details": [ { "@type": "type.googleapis.com/google.rpc.PreconditionFailure", "violations": [ { "type": "constraints/gcp.restrictNonCmekServices", "subject": "orgpolicy:projects/FIRESTORE_PROJECT", "description": "Constraint 'constraints/gcp.restrictNonCmekServices' violated for 'projects/FIRESTORE_PROJECT' attempting to perform the operation 'google.firestore.admin.v1.FirestoreAdmin.CreateDatabase' with violated value 'firestore.googleapis.com'. See https://cloud.google.com/resource-manager/docs/organization-policy/org-policy-constraints for more information." } ]
Ograniczanie użycia kluczy CMEK
Aby ograniczyć klucze Cloud KMS używane do zabezpieczenia za pomocą klucza CMEK, skonfiguruj ograniczenie constraints/gcp.restrictCmekCryptoKeyProjects.
W przypadku ograniczenia listy akceptowane wartości to wskaźniki hierarchii zasobów (np. projects/PROJECT_ID, under:folders/FOLDER_ID i under:organizations/ORGANIZATION_ID). Aby użyć tego ograniczenia, skonfiguruj listę wskaźników hierarchii zasobów i ustaw ograniczenie na Zezwalaj.
Ta konfiguracja ogranicza obsługiwane usługi, dzięki czemu klucze CMEK można wybierać tylko z wymienionych projektów, folderów i organizacji. Żądania utworzenia zasobów chronionych kluczem CMEK w skonfigurowanych usługach nie powiodą się bez klucza Cloud Firestore z jednego z dozwolonych zasobów.
W tym przykładzie w bazach danych chronionych za pomocą klucza CMEK w określonym projekcie dozwolone są tylko klucze z ALLOWED_KEY_PROJECT_ID:
gcloud resource-manager org-policies allow gcp.restrictCmekCryptoKeyProjects \ under:projects/ALLOWED_KEY_PROJECT_ID \ --project=FIRESTORE_PROJECT
Gdy zasada zacznie obowiązywać, w przypadku naruszenia ograniczenia otrzymasz wyjątek FAILED_PRECONDITION i komunikat o błędzie. Wyjątek wygląda tak:
{ "error": { "code": 400, "message": "Constraint 'constraints/gcp.restrictCmekCryptoKeyProjects' violated for 'projects/FIRESTORE_PROJECT' attempting to perform the operation 'google.firestore.admin.v1.FirestoreAdmin.CreateDatabase' with violated value 'projects/{NOT_ALLOWED_KEY_PROJECT}'. See https://cloud.google.com/resource-manager/docs/organization-policy/org-policy-constraints for more information.", "status": "FAILED_PRECONDITION", "details": [ { "@type": "type.googleapis.com/google.rpc.PreconditionFailure", "violations": [ { "type": "constraints/gcp.restrictCmekCryptoKeyProjects", "subject": "orgpolicy:projects/FIRESTORE_PROJECT", "description": "Constraint 'constraints/gcp.restrictCmekCryptoKeyProjects' violated for 'projects/FIRESTORE_PROJECT' attempting to perform the operation 'google.firestore.admin.v1.FirestoreAdmin.CreateDatabase' with violated value 'projects/{NOT_ALLOWED_KEY_PROJECT}'. See https://cloud.google.com/resource-manager/docs/organization-policy/org-policy-constraints for more information." } ] } ] } }